@@ -280,6 +280,17 @@ class PostgresConnection(DBAPI):
             AND pg_index.indisprimary
         """
 
+        otherKeyQuery = """
+        SELECT pg_index.indisprimary,
+            pg_catalog.pg_get_indexdef(pg_index.indexrelid)
+        FROM pg_catalog.pg_class c, pg_catalog.pg_class c2,
+            pg_catalog.pg_index AS pg_index
+        WHERE c.relname = %s
+            AND c.oid = pg_index.indrelid
+            AND pg_index.indexrelid = c2.oid
+            AND NOT pg_index.indisprimary
+        """
+
         keyData = self.queryAll(keyQuery % self.sqlrepr(tableName))
         keyRE = re.compile(r"\((.+)\) REFERENCES (.+)\(")
         keymap = {}
@@ -306,6 +317,18 @@ class PostgresConnection(DBAPI):
             assert primaryKey.endswith('"')
             primaryKey = primaryKey[1:-1]
 
+        otherData = self.queryAll(otherKeyQuery % self.sqlrepr(tableName))
+        otherRE = primaryRE
+        otherKeys = []
+        for isPrimary, indexDef in otherData:
+            match = otherRE.search(indexDef)
+            assert match, "Unparseable constraint definition: %r" % indexDef
+            otherKey = match.group(1)
+            if otherKey.startswith('"'):
+                assert otherKey.endswith('"')
+                otherKey = otherKey[1:-1]
+            otherKeys.append(otherKey)
+
         colData = self.queryAll(colQuery % self.sqlrepr(tableName))
         results = []
         if self.unicodeCols:
@@ -332,6 +355,8 @@ class PostgresConnection(DBAPI):
                 kw['default'] = self.defaultFromSchema(colClass, defaultstr)
             elif not notnull:
                 kw['default'] = None
+            if field in otherKeys:
+                kw['alternateID'] = True
             results.append(colClass(**kw))
         return results
 
@@ -396,10 +421,23 @@ class PostgresConnection(DBAPI):
         cur = conn.cursor()
         # We must close the transaction with a commit so that
         # the CREATE DATABASE can work (which can't be in a transaction):
-        self._executeRetry(conn, cur, 'COMMIT')
-        self._executeRetry(conn, cur, '%s DATABASE %s' % (op, self.db))
-        cur.close()
-        conn.close()
+        try:
+            self._executeRetry(conn, cur, 'COMMIT')
+            self._executeRetry(conn, cur, '%s DATABASE %s' % (op, self.db))
+        finally:
+            cur.close()
+            conn.close()
+
+    def listTables(self):
+        return [v[0] for v in self.queryAll(
+            """SELECT c.relname FROM pg_catalog.pg_class c
+            LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
+            WHERE c.relkind IN ('r','') AND
+            n.nspname NOT IN ('pg_catalog', 'pg_toast') AND
+            pg_catalog.pg_table_is_visible(c.oid)""")]
+
+    def listDatabases(self):
+        return [v[0] for v in self.queryAll("SELECT datname FROM pg_database")]
 
     def createEmptyDatabase(self):
         self._createOrDropDatabase()
